﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CsFileCopy
{
    /// <summary>
    /// お気に入りの追加を行うダイアログです。
    /// </summary>
    public partial class AddFavoriteDialog : Form
    {
        /// <summary>
        /// 抽出元フォルダー
        /// </summary>
        public string SourceFolder
        {
            set
            {
                extractFolderBox.Text = value;
            }
        }

        /// <summary>
        /// 抽出対象ファイル
        /// </summary>
        public string ExtractFile
        {
            set
            {
                extractFileBox.Text = value;
            }
        }
        
        /// <summary>
        /// 抽出除外ファイル
        /// </summary>
        public string ExcludeFile
        {
            set
            {
                excludeFileBox.Text = value;
            }
        }

        /// <summary>
        /// 抽出先フォルダー
        /// </summary>
        public string DestinationFolder
        {
            set
            {
                destinationFolderBox.Text = value;
            }
        }

        public AddFavoriteDialog()
        {
            InitializeComponent();
        }

        /// <summary>
        /// お気に入りに追加ダイアログのロード時の処理です。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void AddFavoriteDialog_Load(object sender, EventArgs e)
        {
            titleBox.Select();
        }

        /// <summary>
        /// キャンセルボタンが押された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void cancelButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        /// <summary>
        /// 追加ボタンが押された時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void addButton_Click(object sender, EventArgs e)
        {
            if (titleBox.Text.Trim().Length == 0)
            {
                MessageUtil.ShowAlert("タイトルを入力してください。");
                return;
            }

            if (extractFolderBox.Text.Trim().Length == 0
                && extractFileBox.Text.Trim().Length ==0
                && excludeFileBox.Text.Trim().Length == 0
                && destinationFolderBox.Text.Trim().Length == 0)
            {
                MessageUtil.ShowAlert("抽出元フォルダー、抽出対象ファイル、抽出除外ファイル、抽出先フォルダーのいずれか1つは入力してください。");
                return;
            }

            Favorites favorites = new Favorites();

            FavoriteData favorite = new FavoriteData();
            favorite.Title = titleBox.Text;
            favorite.ExtractFolder = extractFolderBox.Text;
            favorite.ExtractFile = extractFileBox.Text;
            favorite.ExcludeFile = excludeFileBox.Text;
            favorite.DestinationFolder = destinationFolderBox.Text;

            favorites.AddFavorite(favorite);

            MessageUtil.ShowInfo("お気に入りを1件追加しました。");

            Close();
        }
    }
}
